summaryrefslogtreecommitdiff
path: root/src/main/org/apache/tools/ant/taskdefs
diff options
context:
space:
mode:
authorGintas Grigelionis <gintas@apache.org>2018-04-20 22:05:10 +0200
committerGintas Grigelionis <gintas@apache.org>2018-04-20 22:05:10 +0200
commit5f4c43ddc3d0b67f3c4bf6f66cfc95227537c6b9 (patch)
tree98eb449e21ca089b185c1fcf15bd8fda89b63904 /src/main/org/apache/tools/ant/taskdefs
parent46311e1730deaa99fa7fd40604a8513f74c24de2 (diff)
downloadant-5f4c43ddc3d0b67f3c4bf6f66cfc95227537c6b9.tar.gz
Checkstyle/spelling
Diffstat (limited to 'src/main/org/apache/tools/ant/taskdefs')
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/Ant.java4
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/Checksum.java2
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/Chmod.java2
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/Concat.java6
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/Deltree.java12
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/DependSet.java2
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/Get.java4
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/Javac.java14
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/Parallel.java8
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/Redirector.java8
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/Rmic.java8
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/SubAnt.java2
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/TaskOutputStream.java4
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/WaitFor.java4
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/XmlProperty.java2
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/Zip.java2
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/compilers/Kjc.java2
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/email/Message.java8
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/optional/SchemaValidate.java2
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/optional/TraXLiaison.java4
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/optional/ejb/EjbJar.java8
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/optional/ejb/OrionDeploymentTool.java2
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/optional/ejb/WeblogicDeploymentTool.java86
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/optional/ejb/WeblogicTOPLinkDeploymentTool.java2
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/optional/ejb/WebsphereDeploymentTool.java54
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/optional/jsp/WLJspc.java24
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/optional/jsp/compilers/DefaultJspCompilerAdapter.java6
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/optional/junit/JUnitTask.java2
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/optional/junit/SummaryJUnitResultFormatter.java2
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/optional/native2ascii/Native2AsciiAdapterFactory.java6
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/optional/net/FTP.java2
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/optional/net/FTPTaskMirrorImpl.java10
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/optional/sound/AntSoundPlayer.java3
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/rmic/KaffeRmic.java2
-rw-r--r--src/main/org/apache/tools/ant/taskdefs/rmic/RmicAdapterFactory.java2
35 files changed, 147 insertions, 164 deletions
diff --git a/src/main/org/apache/tools/ant/taskdefs/Ant.java b/src/main/org/apache/tools/ant/taskdefs/Ant.java
index 7b89907f0..ca3251995 100644
--- a/src/main/org/apache/tools/ant/taskdefs/Ant.java
+++ b/src/main/org/apache/tools/ant/taskdefs/Ant.java
@@ -467,8 +467,8 @@ public class Ant extends Task {
/**
* Get the default build file name to use when launching the task.
* <p>
- * This function may be overriden by providers of custom ProjectHelper so they can implement easily their sub
- * launcher.
+ * This function may be overridden by providers of custom ProjectHelper so they can easily
+ * implement their sublauncher.
*
* @return the name of the default file
* @since Ant 1.8.0
diff --git a/src/main/org/apache/tools/ant/taskdefs/Checksum.java b/src/main/org/apache/tools/ant/taskdefs/Checksum.java
index 96327233e..fdadba419 100644
--- a/src/main/org/apache/tools/ant/taskdefs/Checksum.java
+++ b/src/main/org/apache/tools/ant/taskdefs/Checksum.java
@@ -154,7 +154,7 @@ public class Checksum extends MatchingTask implements Condition {
private int readBufferSize = BUFFER_SIZE;
/**
- * Formater for the checksum file.
+ * Formatter for the checksum file.
*/
private MessageFormat format = FormatElement.getDefault().getFormat();
diff --git a/src/main/org/apache/tools/ant/taskdefs/Chmod.java b/src/main/org/apache/tools/ant/taskdefs/Chmod.java
index f97d4ee69..c9db7b9b5 100644
--- a/src/main/org/apache/tools/ant/taskdefs/Chmod.java
+++ b/src/main/org/apache/tools/ant/taskdefs/Chmod.java
@@ -190,7 +190,7 @@ public class Chmod extends ExecuteOn {
}
}
} else if (isValidOs()) {
- // we are chmodding the given directory
+ // we are chmoding the given directory
Execute execute = prepareExec();
Commandline cloned = (Commandline) cmdl.clone();
cloned.createArgument().setValue(defaultSet.getDir(getProject())
diff --git a/src/main/org/apache/tools/ant/taskdefs/Concat.java b/src/main/org/apache/tools/ant/taskdefs/Concat.java
index b58928d4e..ca4fe9153 100644
--- a/src/main/org/apache/tools/ant/taskdefs/Concat.java
+++ b/src/main/org/apache/tools/ant/taskdefs/Concat.java
@@ -214,7 +214,7 @@ public class Concat extends Task implements ResourceCollection {
/**
* This class reads from each of the source files in turn.
- * The concatentated result can then be filtered as
+ * The concatenated result can then be filtered as
* a single stream.
*/
private final class MultiReader<S> extends Reader {
@@ -623,7 +623,7 @@ public class Concat extends Task implements ResourceCollection {
* Sets the behavior when no source resource files are available. If set to
* <code>false</code> the destination file will always be created.
* Defaults to <code>true</code>.
- * @param ignoreEmpty if false honour destinationfile creation.
+ * @param ignoreEmpty if false, honour destination file creation.
* @since Ant 1.8.0
*/
public void setIgnoreEmpty(boolean ignoreEmpty) {
@@ -698,7 +698,7 @@ public class Concat extends Task implements ResourceCollection {
/**
* This method adds text which appears in the 'concat' element.
- * @param text the text to be concated.
+ * @param text the text to be concatenated.
*/
public void addText(String text) {
if (textBuffer == null) {
diff --git a/src/main/org/apache/tools/ant/taskdefs/Deltree.java b/src/main/org/apache/tools/ant/taskdefs/Deltree.java
index 4d20e0171..ec967d0e1 100644
--- a/src/main/org/apache/tools/ant/taskdefs/Deltree.java
+++ b/src/main/org/apache/tools/ant/taskdefs/Deltree.java
@@ -81,18 +81,16 @@ public class Deltree extends Task {
// the comparison of absolute path and canonical path
// catches this
- // if (dir.getCanonicalPath().equals(dir.getAbsolutePath())) {
+ // if (dir.getCanonicalPath().equals(dir.getAbsolutePath())) {
// (costin) It will not work if /home/costin is symlink to
- // /da0/home/costin ( taz for example )
+ // /da0/home/costin (taz for example)
for (String s : dir.list()) {
File f = new File(dir, s);
if (f.isDirectory()) {
removeDir(f);
- } else {
- if (!f.delete()) {
- throw new BuildException("Unable to delete file "
- + f.getAbsolutePath());
- }
+ } else if (!f.delete()) {
+ throw new BuildException("Unable to delete file "
+ + f.getAbsolutePath());
}
}
if (!dir.delete()) {
diff --git a/src/main/org/apache/tools/ant/taskdefs/DependSet.java b/src/main/org/apache/tools/ant/taskdefs/DependSet.java
index b02651034..6fb946337 100644
--- a/src/main/org/apache/tools/ant/taskdefs/DependSet.java
+++ b/src/main/org/apache/tools/ant/taskdefs/DependSet.java
@@ -225,7 +225,7 @@ public class DependSet extends MatchingTask {
datesel.setMillis(System.currentTimeMillis());
datesel.setWhen(TimeComparison.AFTER);
// don't whine because a file has changed during the last
- // second (or whathever our current granularity may be)
+ // second (or whatever our current granularity may be)
datesel.setGranularity(0);
logFuture(targets, datesel);
diff --git a/src/main/org/apache/tools/ant/taskdefs/Get.java b/src/main/org/apache/tools/ant/taskdefs/Get.java
index 077f7eb4d..b44a0118f 100644
--- a/src/main/org/apache/tools/ant/taskdefs/Get.java
+++ b/src/main/org/apache/tools/ant/taskdefs/Get.java
@@ -93,7 +93,7 @@ public class Get extends Task {
DEFAULT_AGENT_PREFIX + "/"
+ Main.getShortAntVersion());
- // Store headers as key/value pair without duplicate in keyz
+ // Store headers as key/value pair without duplicate in keys
private Map<String, String> headers = new LinkedHashMap<>();
/**
@@ -212,7 +212,7 @@ public class Get extends Task {
return true;
}
- //dont do any progress, unless asked
+ // don't do any progress, unless asked
if (progress == null) {
progress = new NullProgress();
}
diff --git a/src/main/org/apache/tools/ant/taskdefs/Javac.java b/src/main/org/apache/tools/ant/taskdefs/Javac.java
index ca8a82ebf..1cf9964b6 100644
--- a/src/main/org/apache/tools/ant/taskdefs/Javac.java
+++ b/src/main/org/apache/tools/ant/taskdefs/Javac.java
@@ -1450,8 +1450,8 @@ public class Javac extends MatchingTask {
if (!"package-info.java".equals(f.getName())) {
continue;
}
- final String path = FILE_UTILS.removeLeadingPath(srcDir, f).
- replace(File.separatorChar, '/');
+ final String path = FILE_UTILS.removeLeadingPath(srcDir, f)
+ .replace(File.separatorChar, '/');
final String suffix = "/package-info.java";
if (!path.endsWith(suffix)) {
log("anomalous package-info.java path: " + path, Project.MSG_WARN);
@@ -1643,7 +1643,7 @@ public class Javac extends MatchingTask {
private static void findModules(
final File root,
String pattern,
- final Map<String,Collection<File>> collector) {
+ final Map<String, Collection<File>> collector) {
pattern = pattern
.replace('/', File.separatorChar)
.replace('\\', File.separatorChar);
@@ -1684,16 +1684,14 @@ public class Javac extends MatchingTask {
final String pathToModule,
final String pathInModule,
final Map<String,Collection<File>> collector) {
- final FileUtils fu = FileUtils.getFileUtils();
- final File f = fu.resolveFile(root, pathToModule);
+ final File f = FileUtils.getFileUtils().resolveFile(root, pathToModule);
if (!f.isDirectory()) {
return;
}
for (File module : f.listFiles(File::isDirectory)) {
final String moduleName = module.getName();
- final File moduleSourceRoot = pathInModule == null ?
- module :
- new File(module, pathInModule);
+ final File moduleSourceRoot = pathInModule == null
+ ? module : new File(module, pathInModule);
Collection<File> moduleRoots = collector.computeIfAbsent(moduleName, k -> new ArrayList<>());
moduleRoots.add(moduleSourceRoot);
}
diff --git a/src/main/org/apache/tools/ant/taskdefs/Parallel.java b/src/main/org/apache/tools/ant/taskdefs/Parallel.java
index 0922b9f84..d6b5604de 100644
--- a/src/main/org/apache/tools/ant/taskdefs/Parallel.java
+++ b/src/main/org/apache/tools/ant/taskdefs/Parallel.java
@@ -58,7 +58,7 @@ public class Parallel extends Task
private List<Task> tasks = new ArrayList<>();
/**
- * Add a nested task to execute parallel (asynchron).
+ * Add a nested task to execute in parallel (asynchronously).
* <p>
* @param nestedTask Nested task to be executed in parallel.
* must not be null.
@@ -96,7 +96,7 @@ public class Parallel extends Task
*/
private boolean failOnAny;
- /** The dameon task list if any */
+ /** The daemon task list if any */
private TaskList daemonTasks;
/** Accumulation of exceptions messages from all nested tasks */
@@ -215,8 +215,8 @@ public class Parallel extends Task
*/
private void updateThreadCounts() {
if (numThreadsPerProcessor != 0) {
- numThreads = Runtime.getRuntime().availableProcessors() *
- numThreadsPerProcessor;
+ numThreads = Runtime.getRuntime().availableProcessors()
+ * numThreadsPerProcessor;
}
}
diff --git a/src/main/org/apache/tools/ant/taskdefs/Redirector.java b/src/main/org/apache/tools/ant/taskdefs/Redirector.java
index 036a1bf2c..50183d6f5 100644
--- a/src/main/org/apache/tools/ant/taskdefs/Redirector.java
+++ b/src/main/org/apache/tools/ant/taskdefs/Redirector.java
@@ -707,8 +707,8 @@ public class Redirector {
/** outStreams */
private void outStreams() {
if (out != null && out.length > 0) {
- final String logHead = "Output " +
- ((appendOut) ? "appended" : "redirected") + " to ";
+ final String logHead = "Output "
+ + ((appendOut) ? "appended" : "redirected") + " to ";
outputStream = foldFiles(out, logHead, Project.MSG_VERBOSE,
appendOut, createEmptyFilesOut);
}
@@ -729,8 +729,8 @@ public class Redirector {
private void errorStreams() {
if (error != null && error.length > 0) {
- final String logHead = "Error " +
- ((appendErr) ? "appended" : "redirected") + " to ";
+ final String logHead = "Error "
+ + ((appendErr) ? "appended" : "redirected") + " to ";
errorStream = foldFiles(error, logHead, Project.MSG_VERBOSE,
appendErr, createEmptyFilesErr);
} else if (!(logError || outputStream == null) && errorProperty == null) {
diff --git a/src/main/org/apache/tools/ant/taskdefs/Rmic.java b/src/main/org/apache/tools/ant/taskdefs/Rmic.java
index fdfd81bf8..55cb8bce9 100644
--- a/src/main/org/apache/tools/ant/taskdefs/Rmic.java
+++ b/src/main/org/apache/tools/ant/taskdefs/Rmic.java
@@ -613,9 +613,8 @@ public class Rmic extends MatchingTask {
if (verify) {
log("Verify has been turned on.", Project.MSG_VERBOSE);
}
- RmicAdapter adapter =
- nestedAdapter != null ? nestedAdapter :
- RmicAdapterFactory.getRmic(getCompiler(), this,
+ RmicAdapter adapter = nestedAdapter != null ? nestedAdapter
+ : RmicAdapterFactory.getRmic(getCompiler(), this,
createCompilerClasspath());
// now we need to populate the compiler adapter
@@ -727,8 +726,7 @@ public class Rmic extends MatchingTask {
try {
if (filtering) {
FILE_UTILS.copyFile(oldFile, newFile,
- new FilterSetCollection(getProject()
- .getGlobalFilterSet()));
+ new FilterSetCollection(getProject().getGlobalFilterSet()));
} else {
FILE_UTILS.copyFile(oldFile, newFile);
}
diff --git a/src/main/org/apache/tools/ant/taskdefs/SubAnt.java b/src/main/org/apache/tools/ant/taskdefs/SubAnt.java
index 3213d25f1..1b59581bb 100644
--- a/src/main/org/apache/tools/ant/taskdefs/SubAnt.java
+++ b/src/main/org/apache/tools/ant/taskdefs/SubAnt.java
@@ -82,7 +82,7 @@ public class SubAnt extends Task {
/**
* Get the default build file name to use when launching the task.
* <p>
- * This function may be overriden by providers of custom ProjectHelper so
+ * This function may be overridden by providers of custom ProjectHelper so
* they can implement easily their sub launcher.
* </p>
*
diff --git a/src/main/org/apache/tools/ant/taskdefs/TaskOutputStream.java b/src/main/org/apache/tools/ant/taskdefs/TaskOutputStream.java
index 2ba5a618b..eb6853fea 100644
--- a/src/main/org/apache/tools/ant/taskdefs/TaskOutputStream.java
+++ b/src/main/org/apache/tools/ant/taskdefs/TaskOutputStream.java
@@ -24,8 +24,8 @@ import java.io.OutputStream;
import org.apache.tools.ant.Task;
/**
- * Redirects text written to a stream thru the standard
- * ant logging mechanism. This class is useful for integrating
+ * Redirects text written to a stream through the standard
+ * Ant logging mechanism. This class is useful for integrating
* with tools that write to System.out and System.err. For example,
* the following will cause all text written to System.out to be
* logged with "info" priority:
diff --git a/src/main/org/apache/tools/ant/taskdefs/WaitFor.java b/src/main/org/apache/tools/ant/taskdefs/WaitFor.java
index af7372fe9..28d0d883e 100644
--- a/src/main/org/apache/tools/ant/taskdefs/WaitFor.java
+++ b/src/main/org/apache/tools/ant/taskdefs/WaitFor.java
@@ -253,8 +253,8 @@ public class WaitFor extends ConditionBase {
}
/**
- * Convert the value to a multipler (millisecond to unit).
- * @return a multipler (a long value)
+ * Convert the value to a multiplier (millisecond to unit).
+ * @return a multiplier (a long value)
*/
public long getMultiplier() {
String key = getValue().toLowerCase(Locale.ENGLISH);
diff --git a/src/main/org/apache/tools/ant/taskdefs/XmlProperty.java b/src/main/org/apache/tools/ant/taskdefs/XmlProperty.java
index f4d7886c9..03e6ace14 100644
--- a/src/main/org/apache/tools/ant/taskdefs/XmlProperty.java
+++ b/src/main/org/apache/tools/ant/taskdefs/XmlProperty.java
@@ -212,7 +212,7 @@ public class XmlProperty extends Task {
}
/**
- * @return the xmlCatalog as the entityresolver.
+ * @return the xmlCatalog as the EntityResolver.
*/
protected EntityResolver getEntityResolver() {
return xmlCatalog;
diff --git a/src/main/org/apache/tools/ant/taskdefs/Zip.java b/src/main/org/apache/tools/ant/taskdefs/Zip.java
index bf61812fd..65bfdec9e 100644
--- a/src/main/org/apache/tools/ant/taskdefs/Zip.java
+++ b/src/main/org/apache/tools/ant/taskdefs/Zip.java
@@ -2196,7 +2196,7 @@ public class Zip extends MatchingTask {
* central directory - which is what <em>as-needed</em> may result
* in. Java5 and Microsoft Visual Studio's Extension loader are
* known to fconsider the archive broken in such cases. If you
- * are targeting such an archiver uset the value <em>never</em>
+ * are targeting such an archiver use the value <em>never</em>
* unless you know you need Zip64 extensions.</p>
*
* @since Ant 1.9.1
diff --git a/src/main/org/apache/tools/ant/taskdefs/compilers/Kjc.java b/src/main/org/apache/tools/ant/taskdefs/compilers/Kjc.java
index d3c87f911..1506519de 100644
--- a/src/main/org/apache/tools/ant/taskdefs/compilers/Kjc.java
+++ b/src/main/org/apache/tools/ant/taskdefs/compilers/Kjc.java
@@ -67,7 +67,7 @@ public class Kjc extends DefaultCompilerAdapter {
cmd.createArgument().setFile(destDir);
}
- // generate the clsspath
+ // generate the classpath
cmd.createArgument().setValue("-classpath");
Path cp = new Path(project);
diff --git a/src/main/org/apache/tools/ant/taskdefs/email/Message.java b/src/main/org/apache/tools/ant/taskdefs/email/Message.java
index 0b763e425..ec10e99a9 100644
--- a/src/main/org/apache/tools/ant/taskdefs/email/Message.java
+++ b/src/main/org/apache/tools/ant/taskdefs/email/Message.java
@@ -109,15 +109,13 @@ public class Message extends ProjectComponent {
* @param ps The print stream to write to
* @throws IOException if an error occurs
*/
- public void print(PrintStream ps)
- throws IOException {
+ public void print(PrintStream ps) throws IOException {
// We need character encoding aware printing here.
// So, using BufferedWriter over OutputStreamWriter instead of PrintStream
BufferedWriter out = null;
try {
- out
- = charset != null ? new BufferedWriter(new OutputStreamWriter(ps, charset))
- : new BufferedWriter(new OutputStreamWriter(ps));
+ out = charset == null ? new BufferedWriter(new OutputStreamWriter(ps))
+ : new BufferedWriter(new OutputStreamWriter(ps, charset));
if (messageSource != null) {
// Read message from a file
try (Reader freader = getReader(messageSource);
diff --git a/src/main/org/apache/tools/ant/taskdefs/optional/SchemaValidate.java b/src/main/org/apache/tools/ant/taskdefs/optional/SchemaValidate.java
index f61a93bd4..36b52f32c 100644
--- a/src/main/org/apache/tools/ant/taskdefs/optional/SchemaValidate.java
+++ b/src/main/org/apache/tools/ant/taskdefs/optional/SchemaValidate.java
@@ -41,7 +41,7 @@ import org.xml.sax.XMLReader;
* This task validates XML schema documents. It requires an XML parser
* that handles the relevant SAX, Xerces or JAXP options.
*
- * To resolve remote referencies, Ant may need its proxy set up, using the
+ * To resolve remote references, Ant may need its proxy set up, using the
* setproxy task.
*
* Hands off most of the work to its parent, {@link XMLValidateTask}
diff --git a/src/main/org/apache/tools/ant/taskdefs/optional/TraXLiaison.java b/src/main/org/apache/tools/ant/taskdefs/optional/TraXLiaison.java
index ac2f06729..ed1a92790 100644
--- a/src/main/org/apache/tools/ant/taskdefs/optional/TraXLiaison.java
+++ b/src/main/org/apache/tools/ant/taskdefs/optional/TraXLiaison.java
@@ -367,9 +367,7 @@ public class TraXLiaison implements XSLTLiaison4, ErrorListener, XSLTLoggerAware
* Sets the parameters for the transformer.
*/
private void setTransformationParameters() {
- for (Map.Entry<String, Object> entry : params.entrySet()) {
- transformer.setParameter(entry.getKey(), entry.getValue());
- }
+ params.forEach((key, value) -> transformer.setParameter(key, value));
}
/**
diff --git a/src/main/org/apache/tools/ant/taskdefs/optional/ejb/EjbJar.java b/src/main/org/apache/tools/ant/taskdefs/optional/ejb/EjbJar.java
index afd440d45..1ae4b71ce 100644
--- a/src/main/org/apache/tools/ant/taskdefs/optional/ejb/EjbJar.java
+++ b/src/main/org/apache/tools/ant/taskdefs/optional/ejb/EjbJar.java
@@ -204,7 +204,7 @@ public class EjbJar extends MatchingTask {
/** Instance variable that stores the suffix for the generated jarfile. */
private String genericJarSuffix = "-generic.jar";
- /** Instance variable that stores the CMP version for the jboss jarfile. */
+ /** Instance variable that stores the CMP version for the JBoss jarfile. */
private String cmpVersion = CMPVersion.CMP1_0;
/** The list of deployment tools we are going to run. */
@@ -236,7 +236,7 @@ public class EjbJar extends MatchingTask {
}
/**
- * Adds a deployment tool for Weblogic server.
+ * Adds a deployment tool for WebLogic server.
*
* @return the deployment tool instance to be configured.
*/
@@ -247,7 +247,7 @@ public class EjbJar extends MatchingTask {
}
/**
- * Adds a deployment tool for Websphere 4.0 server.
+ * Adds a deployment tool for WebSphere 4.0 server.
*
* @return the deployment tool instance to be configured.
*/
@@ -309,7 +309,7 @@ public class EjbJar extends MatchingTask {
}
/**
- * Adds a deployment tool for Weblogic when using the Toplink
+ * Adds a deployment tool for WebLogic when using the TOPLink
* Object-Relational mapping.
*
* @return the deployment tool instance to be configured.
diff --git a/src/main/org/apache/tools/ant/taskdefs/optional/ejb/OrionDeploymentTool.java b/src/main/org/apache/tools/ant/taskdefs/optional/ejb/OrionDeploymentTool.java
index 8752583f6..bd47c8bba 100644
--- a/src/main/org/apache/tools/ant/taskdefs/optional/ejb/OrionDeploymentTool.java
+++ b/src/main/org/apache/tools/ant/taskdefs/optional/ejb/OrionDeploymentTool.java
@@ -35,7 +35,7 @@ public class OrionDeploymentTool extends GenericDeploymentTool {
protected static final String ORION_DD = "orion-ejb-jar.xml";
- /** Instance variable that stores the suffix for the jboss jarfile. */
+ /** Instance variable that stores the suffix for the JBoss jarfile. */
private String jarSuffix = ".jar";
/**
diff --git a/src/main/org/apache/tools/ant/taskdefs/optional/ejb/WeblogicTOPLinkDeploymentTool.java b/src/main/org/apache/tools/ant/taskdefs/optional/ejb/WeblogicTOPLinkDeploymentTool.java
index 15edf4687..8a7a8b413 100644
--- a/src/main/org/apache/tools/ant/taskdefs/optional/ejb/WeblogicTOPLinkDeploymentTool.java
+++ b/src/main/org/apache/tools/ant/taskdefs/optional/ejb/WeblogicTOPLinkDeploymentTool.java
@@ -25,7 +25,7 @@ import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Project;
/**
- * Deployment tool for Weblogic TOPLink.
+ * Deployment tool for WebLogic TOPLink.
*/
public class WeblogicTOPLinkDeploymentTool extends WeblogicDeploymentTool {
diff --git a/src/main/org/apache/tools/ant/taskdefs/optional/ejb/WebsphereDeploymentTool.java b/src/main/org/apache/tools/ant/taskdefs/optional/ejb/WebsphereDeploymentTool.java
index 3094b0de8..3caea0680 100644
--- a/src/main/org/apache/tools/ant/taskdefs/optional/ejb/WebsphereDeploymentTool.java
+++ b/src/main/org/apache/tools/ant/taskdefs/optional/ejb/WebsphereDeploymentTool.java
@@ -37,9 +37,9 @@ import org.apache.tools.ant.types.Path;
import org.apache.tools.ant.util.FileUtils;
/**
- * Websphere deployment tool that augments the ejbjar task.
- * Searches for the websphere specific deployment descriptors and
- * adds them to the final ejb jar file. Websphere has two specific descriptors for session
+ * WebSphere deployment tool that augments the ejbjar task.
+ * Searches for the WebSphere specific deployment descriptors and
+ * adds them to the final ejb jar file. WebSphere has two specific descriptors for session
* beans:
* <ul>
* <li>ibm-ejb-jar-bnd.xmi</li>
@@ -53,7 +53,7 @@ import org.apache.tools.ant.util.FileUtils;
* In terms of WebSphere, the generation of container code and stubs is
* called <code>deployment</code>. This step can be performed by the websphere
* element as part of the jar generation process. If the switch
- * <code>ejbdeploy</code> is on, the ejbdeploy tool from the websphere toolset
+ * <code>ejbdeploy</code> is on, the ejbdeploy tool from the WebSphere toolset
* is called for every ejb-jar. Unfortunately, this step only works, if you
* use the ibm jdk. Otherwise, the rmic (called by ejbdeploy) throws a
* ClassFormatError. Be sure to switch ejbdeploy off, if run ant with
@@ -78,7 +78,7 @@ public class WebsphereDeploymentTool extends GenericDeploymentTool {
private static final FileUtils FILE_UTILS = FileUtils.getFileUtils();
- /** Instance variable that stores the suffix for the websphere jarfile. */
+ /** Instance variable that stores the suffix for the WebSphere jarfile. */
private String jarSuffix = ".jar";
/** Instance variable that stores the location of the ejb 1.1 DTD file. */
@@ -95,7 +95,7 @@ public class WebsphereDeploymentTool extends GenericDeploymentTool {
/** Indicates if the old CMP location convention is to be used. */
private boolean newCMP = false;
- /** The classpath to the websphere classes. */
+ /** The classpath to the WebSphere classes. */
private Path wasClasspath = null;
/** The DB Vendor name, the EJB is persisted against */
@@ -134,12 +134,12 @@ public class WebsphereDeploymentTool extends GenericDeploymentTool {
/** the scratchdir for the ejbdeploy operation */
private String tempdir = "_ejbdeploy_temp";
- /** the home directory for websphere */
+ /** the home directory for WebSphere */
private File websphereHome;
/**
- * Get the classpath to the websphere classpaths.
- * @return the websphere classpath.
+ * Get the classpath to the WebSphere classpaths.
+ * @return the WebSphere classpath.
*/
public Path createWASClasspath() {
if (wasClasspath == null) {
@@ -149,8 +149,8 @@ public class WebsphereDeploymentTool extends GenericDeploymentTool {
}
/**
- * Set the websphere classpath.
- * @param wasClasspath the websphere classpath.
+ * Set the WebSphere classpath.
+ * @param wasClasspath the WebSphere classpath.
*/
public void setWASClasspath(Path wasClasspath) {
this.wasClasspath = wasClasspath;
@@ -325,10 +325,10 @@ public class WebsphereDeploymentTool extends GenericDeploymentTool {
/**
* Set the value of the newCMP scheme. The old CMP scheme locates the
- * websphere CMP descriptor based on the naming convention where the
- * websphere CMP file is expected to be named with the bean name as the
+ * WebSphere CMP descriptor based on the naming convention where the
+ * WebSphere CMP file is expected to be named with the bean name as the
* prefix. Under this scheme the name of the CMP descriptor does not match
- * the name actually used in the main websphere EJB descriptor. Also,
+ * the name actually used in the main WebSphere EJB descriptor. Also,
* descriptors which contain multiple CMP references could not be used.
* @param newCMP a <code>boolean</code> value.
*/
@@ -517,12 +517,12 @@ public class WebsphereDeploymentTool extends GenericDeploymentTool {
}
/**
- * Helper method invoked by execute() for each websphere jar to be built.
+ * Helper method invoked by execute() for each WebSphere jar to be built.
* Encapsulates the logic of constructing a java task for calling
* websphere.ejbdeploy and executing it.
*
* @param sourceJar java.io.File representing the source (EJB1.1) jarfile.
- * @param destJar java.io.File representing the destination, websphere
+ * @param destJar java.io.File representing the destination, WebSphere
* jarfile.
*/
private void buildWebsphereJar(File sourceJar, File destJar) {
@@ -625,27 +625,27 @@ public class WebsphereDeploymentTool extends GenericDeploymentTool {
}
/**
- * Helper method to check to see if a websphere EBJ1.1 jar needs to be
+ * Helper method to check to see if a WebSphere EJB 1.1 jar needs to be
* rebuilt using ejbdeploy. Called from writeJar it sees if the "Bean"
* classes are the only thing that needs to be updated and either updates
* the Jar with the Bean classfile or returns true, saying that the whole
- * websphere jar needs to be regened with ejbdeploy. This allows faster
+ * WebSphere jar needs to be regenerated with ejbdeploy. This allows faster
* build times for working developers. <p>
*
- * The way websphere ejbdeploy works is it creates wrappers for the
+ * The way WebSphere ejbdeploy works is it creates wrappers for the
* publicly defined methods as they are exposed in the remote interface.
* If the actual bean changes without changing the the method signatures
* then only the bean classfile needs to be updated and the rest of the
- * websphere jar file can remain the same. If the Interfaces, ie. the
+ * WebSphere jar file can remain the same. If the Interfaces, ie. the
* method signatures change or if the xml deployment descriptors changed,
* the whole jar needs to be rebuilt with ejbdeploy. This is not strictly
* true for the xml files. If the JNDI name changes then the jar doesn't
* have to be rebuild, but if the resources references change then it
- * does. At this point the websphere jar gets rebuilt if the xml files
+ * does. At this point the WebSphere jar gets rebuilt if the xml files
* change at all.
*
* @param genericJarFile java.io.File The generic jar file.
- * @param websphereJarFile java.io.File The websphere jar file to check to
+ * @param websphereJarFile java.io.File The WebSphere jar file to check to
* see if it needs to be rebuilt.
* @return true if a rebuild is required.
*/
@@ -662,7 +662,7 @@ public class WebsphereDeploymentTool extends GenericDeploymentTool {
try {
log("Checking if websphere Jar needs to be rebuilt for jar "
+ websphereJarFile.getName(), Project.MSG_VERBOSE);
- // Only go forward if the generic and the websphere file both exist
+ // Only go forward if the generic and the WebSphere file both exist
if (genericJarFile.exists() && genericJarFile.isFile()
&& websphereJarFile.exists() && websphereJarFile.isFile()) {
//open jar files
@@ -678,13 +678,13 @@ public class WebsphereDeploymentTool extends GenericDeploymentTool {
JarEntry je = e.nextElement();
genericEntries.put(je.getName().replace('\\', '/'), je);
}
- //get the list of websphere jar entries
+ // get the list of WebSphere jar entries
for (Enumeration<JarEntry> e = wasJar.entries(); e.hasMoreElements();) {
JarEntry je = e.nextElement();
wasEntries.put(je.getName(), je);
}
- //Cycle Through generic and make sure its in websphere
+ // Cycle through generic and make sure its in WebSphere
genericLoader = getClassLoaderFromJar(genericJarFile);
for (Enumeration<String> e = genericEntries.keys(); e.hasMoreElements();) {
@@ -748,7 +748,7 @@ public class WebsphereDeploymentTool extends GenericDeploymentTool {
newJarStream = new JarOutputStream(Files.newOutputStream(newwasJarFile.toPath()));
newJarStream.setLevel(0);
- //Copy files from old websphere jar
+ // Copy files from old WebSphere jar
for (Enumeration<JarEntry> e = wasEntries.elements(); e.hasMoreElements();) {
JarEntry je = e.nextElement();
@@ -768,7 +768,7 @@ public class WebsphereDeploymentTool extends GenericDeploymentTool {
je = replaceEntries.get(je.getName());
is = genericJar.getInputStream(je);
} else {
- //use fle from original websphere jar
+ // use fle from original WebSphere jar
is = wasJar.getInputStream(je);
}
diff --git a/src/main/org/apache/tools/ant/taskdefs/optional/jsp/WLJspc.java b/src/main/org/apache/tools/ant/taskdefs/optional/jsp/WLJspc.java
index 1c182de84..e5893206b 100644
--- a/src/main/org/apache/tools/ant/taskdefs/optional/jsp/WLJspc.java
+++ b/src/main/org/apache/tools/ant/taskdefs/optional/jsp/WLJspc.java
@@ -34,18 +34,18 @@ import org.apache.tools.ant.types.Path;
/**
* Precompiles JSP's using WebLogic's JSP compiler (weblogic.jspc).
*
- * Tested only on Weblogic 4.5.1 - NT4.0 and Solaris 5.7
+ * Tested only on WebLogic 4.5.1 - NT4.0 and Solaris 5.7
*
* required attributes
- * src : root of source tree for JSP, ie, the document root for your weblogic server
+ * src : root of source tree for JSP, ie, the document root for your WebLogic server
* dest : root of destination directory, what you have set as
- * WorkingDir in the weblogic properties
+ * WorkingDir in the WebLogic properties
* package : start package name under which your JSP's would be compiled
*
* other attributes
* classpath
*
- * A classpath should be set which contains the weblogic classes as well as all
+ * A classpath should be set which contains the WebLogic classes as well as all
* application classes referenced by the JSP. The system classpath is also
* appended when the jspc is called, so you may choose to put everything in
* the classpath while calling Ant. However, since presumably the JSP's will
@@ -55,11 +55,11 @@ import org.apache.tools.ant.types.Path;
* The task checks timestamps on the JSP's and the generated classes, and compiles
* only those files that have changed.
*
- * It follows the weblogic naming convention of putting classes in
+ * It follows the WebLogic naming convention of putting classes in
* <b> _dirName/_fileName.class for dirname/fileName.jsp </b>
*
- * Limitation: It compiles the files thru the Classic compiler only.
- * Limitation: Since it is my experience that weblogic jspc throws out of
+ * Limitation: It compiles the files through the Classic compiler only.
+ * Limitation: Since it is my experience that WebLogic jspc throws out of
* memory error on being given too many files at one go, it is
* called multiple times with one jsp file each.
*
@@ -80,7 +80,7 @@ import org.apache.tools.ant.types.Path;
*/
public class WLJspc extends MatchingTask {
- //TODO Test on other versions of weblogic
+ //TODO Test on other versions of WebLogic
//TODO add more attributes to the task, to take care of all jspc options
//TODO Test on Unix
@@ -134,7 +134,7 @@ public class WLJspc extends MatchingTask {
compileClasspath = compileClasspath.concatSystemClasspath();
- //Weblogic.jspc calls System.exit() ... have to fork
+ // WebLogic jspc calls System.exit() ... have to fork
// Therefore, takes loads of time
// Can pass directories at a time (*.jsp) but easily runs out of
// memory on hefty dirs (even on a Sun)
@@ -157,7 +157,7 @@ public class WLJspc extends MatchingTask {
//Use classic compiler -- can be parameterised?
args[j++] = "-compilerclass";
args[j++] = "sun.tools.javac.Main";
- //Weblogic jspc does not seem to work unless u explicitly set this...
+ // WebLogic jspc does not seem to work unless u explicitly set this...
// Does not take the classpath from the env....
// Am i missing something about the Java task??
args[j++] = "-classpath";
@@ -168,7 +168,7 @@ public class WLJspc extends MatchingTask {
for (String filename : filesToDo) {
//TODO
- // All this to get package according to weblogic standards
+ // All this to get package according to WebLogic standards
// Can be written better... this is too hacky!
// Careful.. similar code in scanDir, but slightly different!!
File jspFile = new File(filename);
@@ -260,7 +260,7 @@ public class WLJspc extends MatchingTask {
File srcFile = new File(this.sourceDirectory, file);
//TODO
// All this to convert source to destination directory according
- // to weblogic standards Can be written better... this is too hacky!
+ // to WebLogic standards - can be written better... this is too hacky!
File jspFile = new File(file);
String parents = jspFile.getParent();
diff --git a/src/main/org/apache/tools/ant/taskdefs/optional/jsp/compilers/DefaultJspCompilerAdapter.java b/src/main/org/apache/tools/ant/taskdefs/optional/jsp/compilers/DefaultJspCompilerAdapter.java
index 8eac9de9f..83da76af0 100644
--- a/src/main/org/apache/tools/ant/taskdefs/optional/jsp/compilers/DefaultJspCompilerAdapter.java
+++ b/src/main/org/apache/tools/ant/taskdefs/optional/jsp/compilers/DefaultJspCompilerAdapter.java
@@ -82,7 +82,7 @@ public abstract class DefaultJspCompilerAdapter
}
/**
- * add a single argument to the argument list, if the value aint null
+ * add a single argument to the argument list, if the value isn't null
* @param cmd the command line
* @param argument The argument
*/
@@ -94,7 +94,7 @@ public abstract class DefaultJspCompilerAdapter
/**
- * add an argument tuple to the argument list, if the value aint null
+ * add an argument tuple to the argument list, if the value isn't null
* @param cmd the command line
* @param argument The argument
* @param value the parameter
@@ -107,7 +107,7 @@ public abstract class DefaultJspCompilerAdapter
}
/**
- * add an argument tuple to the arg list, if the file parameter aint null
+ * add an argument tuple to the arg list, if the file parameter isn't null
* @param cmd the command line
* @param argument The argument
* @param file the parameter
diff --git a/src/main/org/apache/tools/ant/taskdefs/optional/junit/JUnitTask.java b/src/main/org/apache/tools/ant/taskdefs/optional/junit/JUnitTask.java
index 7d8eb6a8d..a3e150688 100644
--- a/src/main/org/apache/tools/ant/taskdefs/optional/junit/JUnitTask.java
+++ b/src/main/org/apache/tools/ant/taskdefs/optional/junit/JUnitTask.java
@@ -2357,7 +2357,7 @@ public class JUnitTask extends Task {
/**
* Checks if a given folder is an unpacked module.
- * @param root the fodler to be checked
+ * @param root the folder to be checked
* @return true if the root is an unpacked module
* @since 1.9.8
*/
diff --git a/src/main/org/apache/tools/ant/taskdefs/optional/junit/SummaryJUnitResultFormatter.java b/src/main/org/apache/tools/ant/taskdefs/optional/junit/SummaryJUnitResultFormatter.java
index 2357283ef..f7ccb5479 100644
--- a/src/main/org/apache/tools/ant/taskdefs/optional/junit/SummaryJUnitResultFormatter.java
+++ b/src/main/org/apache/tools/ant/taskdefs/optional/junit/SummaryJUnitResultFormatter.java
@@ -165,7 +165,7 @@ public class SummaryJUnitResultFormatter
*/
@Override
public void endTestSuite(JUnitTest suite) throws BuildException {
- StringBuilder sb = new StringBuilder("Tests run: ");
+ StringBuilder sb = new StringBuilder("Tests run: ");
sb.append(suite.runCount());
sb.append(", Failures: ");
sb.append(suite.failureCount());
diff --git a/src/main/org/apache/tools/ant/taskdefs/optional/native2ascii/Native2AsciiAdapterFactory.java b/src/main/org/apache/tools/ant/taskdefs/optional/native2ascii/Native2AsciiAdapterFactory.java
index d48da3b69..2a4147fce 100644
--- a/src/main/org/apache/tools/ant/taskdefs/optional/native2ascii/Native2AsciiAdapterFactory.java
+++ b/src/main/org/apache/tools/ant/taskdefs/optional/native2ascii/Native2AsciiAdapterFactory.java
@@ -40,7 +40,7 @@ public class Native2AsciiAdapterFactory {
* vendor
*/
public static String getDefault() {
- if (shouldUseKaffee()) {
+ if (shouldUseKaffe()) {
return KaffeNative2Ascii.IMPLEMENTATION_NAME;
}
return BuiltinNative2Ascii.IMPLEMENTATION_NAME;
@@ -79,7 +79,7 @@ public class Native2AsciiAdapterFactory {
ProjectComponent log,
Path classpath)
throws BuildException {
- if ((shouldUseKaffee() && choice == null)
+ if ((shouldUseKaffe() && choice == null)
|| KaffeNative2Ascii.IMPLEMENTATION_NAME.equals(choice)) {
return new KaffeNative2Ascii();
} else if (SunNative2Ascii.IMPLEMENTATION_NAME.equals(choice)) {
@@ -114,7 +114,7 @@ public class Native2AsciiAdapterFactory {
Native2AsciiAdapter.class);
}
- private static final boolean shouldUseKaffee() {
+ private static final boolean shouldUseKaffe() {
return JavaEnvUtils.isKaffe() || JavaEnvUtils.isClasspathBased();
}
}
diff --git a/src/main/org/apache/tools/ant/taskdefs/optional/net/FTP.java b/src/main/org/apache/tools/ant/taskdefs/optional/net/FTP.java
index 029e2d994..aa69cf7e1 100644
--- a/src/main/org/apache/tools/ant/taskdefs/optional/net/FTP.java
+++ b/src/main/org/apache/tools/ant/taskdefs/optional/net/FTP.java
@@ -1971,7 +1971,7 @@ public class FTP extends Task implements FTPTaskConfig {
instream.close();
boolean success = FTPReply.isPositiveCompletion(ftp.getReplyCode());
if (success) {
- FTPFile [] ftpFiles = ftp.listFiles(tempFile.getName());
+ FTPFile[] ftpFiles = ftp.listFiles(tempFile.getName());
if (ftpFiles.length == 1) {
long remoteTimeStamp = ftpFiles[0].getTimestamp().getTime().getTime();
returnValue = localTimeStamp - remoteTimeStamp;
diff --git a/src/main/org/apache/tools/ant/taskdefs/optional/net/FTPTaskMirrorImpl.java b/src/main/org/apache/tools/ant/taskdefs/optional/net/FTPTaskMirrorImpl.java
index a0f387802..c378b21e0 100644
--- a/src/main/org/apache/tools/ant/taskdefs/optional/net/FTPTaskMirrorImpl.java
+++ b/src/main/org/apache/tools/ant/taskdefs/optional/net/FTPTaskMirrorImpl.java
@@ -1096,13 +1096,7 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
* @since ant 1.6
*/
private boolean isFunctioningAsFile(FTPClient ftp, String dir, FTPFile file) {
- if (file.isDirectory()) {
- return false;
- }
- if (file.isFile()) {
- return true;
- }
- return !isFunctioningAsDirectory(ftp, dir, file);
+ return !file.isDirectory() && (file.isFile() || !isFunctioningAsDirectory(ftp, dir, file));
}
/**
@@ -1357,7 +1351,7 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
ftp.storeFile(tempFile.getName(), instream);
instream.close();
if (FTPReply.isPositiveCompletion(ftp.getReplyCode())) {
- FTPFile [] ftpFiles = ftp.listFiles(tempFile.getName());
+ FTPFile[] ftpFiles = ftp.listFiles(tempFile.getName());
if (ftpFiles.length == 1) {
long remoteTimeStamp = ftpFiles[0].getTimestamp().getTime().getTime();
returnValue = localTimeStamp - remoteTimeStamp;
diff --git a/src/main/org/apache/tools/ant/taskdefs/optional/sound/AntSoundPlayer.java b/src/main/org/apache/tools/ant/taskdefs/optional/sound/AntSoundPlayer.java
index 8570ad83f..e8ca74263 100644
--- a/src/main/org/apache/tools/ant/taskdefs/optional/sound/AntSoundPlayer.java
+++ b/src/main/org/apache/tools/ant/taskdefs/optional/sound/AntSoundPlayer.java
@@ -109,8 +109,7 @@ public class AntSoundPlayer implements LineListener, BuildListener {
if (audioInputStream != null) {
AudioFormat format = audioInputStream.getFormat();
- DataLine.Info info = new DataLine.Info(Clip.class, format,
- AudioSystem.NOT_SPECIFIED);
+ DataLine.Info info = new DataLine.Info(Clip.class, format, AudioSystem.NOT_SPECIFIED);
try {
try {
audioClip = (Clip) AudioSystem.getLine(info);
diff --git a/src/main/org/apache/tools/ant/taskdefs/rmic/KaffeRmic.java b/src/main/org/apache/tools/ant/taskdefs/rmic/KaffeRmic.java
index 896513db1..d47cf2e4e 100644
--- a/src/main/org/apache/tools/ant/taskdefs/rmic/KaffeRmic.java
+++ b/src/main/org/apache/tools/ant/taskdefs/rmic/KaffeRmic.java
@@ -48,7 +48,7 @@ public class KaffeRmic extends DefaultRmicAdapter {
*/
@Override
protected boolean areIiopAndIdlSupported() {
- // actually I don't think Kaffee supports either, but we've
+ // actually I don't think Kaffe supports either, but we've
// accepted the flags prior to 1.10.3
return true;
}
diff --git a/src/main/org/apache/tools/ant/taskdefs/rmic/RmicAdapterFactory.java b/src/main/org/apache/tools/ant/taskdefs/rmic/RmicAdapterFactory.java
index 7226246ac..ae5cf0ab4 100644
--- a/src/main/org/apache/tools/ant/taskdefs/rmic/RmicAdapterFactory.java
+++ b/src/main/org/apache/tools/ant/taskdefs/rmic/RmicAdapterFactory.java
@@ -77,7 +77,7 @@ public final class RmicAdapterFactory {
* <li>kaffe = Kaffe's rmic
* <li><i>a fully qualified classname</i> = the name of a rmic
* adapter
- * <li>weblogic = weblogic compiler
+ * <li>weblogic = WebLogic compiler
* <li>forking = Sun's RMIC by forking a new JVM
* </ul>
*
diff --git a/src/main/org/apache/tools/ant/taskdefs/optional/ejb/WeblogicDeploymentTool.java b/src/main/org/apache/tools/ant/taskdefs/optional/ejb/WeblogicDeploymentTool.java
index e8a868e2f..6698bd6e0 100644
--- a/src/main/org/apache/tools/ant/taskdefs/optional/ejb/WeblogicDeploymentTool.java
+++ b/src/main/org/apache/tools/ant/taskdefs/optional/ejb/WeblogicDeploymentTool.java
@@ -45,11 +45,11 @@ import org.xml.sax.InputSource;
/**
The weblogic element is used to control the weblogic.ejbc compiler for
- generating weblogic EJB jars. Prior to Ant 1.3, the method of locating CMP
+ generating WebLogic EJB jars. Prior to Ant 1.3, the method of locating CMP
descriptors was to use the ejbjar naming convention. So if your ejb-jar was
- called, Customer-ejb-jar.xml, your weblogic descriptor was called Customer-
+ called, Customer-ejb-jar.xml, your WebLogic descriptor was called Customer-
weblogic-ejb-jar.xml and your CMP descriptor had to be Customer-weblogic-cmp-
- rdbms-jar.xml. In addition, the &lt;type-storage&gt; element in the weblogic
+ rdbms-jar.xml. In addition, the &lt;type-storage&gt; element in the WebLogic
descriptor had to be set to the standard name META-INF/weblogic-cmp-rdbms-
jar.xml, as that is where the CMP descriptor was mapped to in the generated
jar.
@@ -61,23 +61,23 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
/** EJB20 id */
public static final String PUBLICID_EJB20
= "-//Sun Microsystems, Inc.//DTD Enterprise JavaBeans 2.0//EN";
- /** Weblogic 5.1.0 id */
+ /** WebLogic 5.1.0 id */
public static final String PUBLICID_WEBLOGIC_EJB510
= "-//BEA Systems, Inc.//DTD WebLogic 5.1.0 EJB//EN";
- /** Weblogic 6.0.0 id */
+ /** WebLogic 6.0.0 id */
public static final String PUBLICID_WEBLOGIC_EJB600
= "-//BEA Systems, Inc.//DTD WebLogic 6.0.0 EJB//EN";
- /** Weblogic 7.0.0 id */
+ /** WebLogic 7.0.0 id */
public static final String PUBLICID_WEBLOGIC_EJB700
= "-//BEA Systems, Inc.//DTD WebLogic 7.0.0 EJB//EN";
/** Weblogic 5.1 dtd location */
protected static final String DEFAULT_WL51_EJB11_DTD_LOCATION
= "/weblogic/ejb/deployment/xml/ejb-jar.dtd";
/** Weblogic 6.0 ejb 1.1 dtd location */
protected static final String DEFAULT_WL60_EJB11_DTD_LOCATION
= "/weblogic/ejb20/dd/xml/ejb11-jar.dtd";
/** Weblogic 6.0 ejb 2.0 dtd location */
protected static final String DEFAULT_WL60_EJB20_DTD_LOCATION
= "/weblogic/ejb20/dd/xml/ejb20-jar.dtd";
@@ -101,13 +101,13 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
/** File utilities instance for copying jars */
private static final FileUtils FILE_UTILS = FileUtils.getFileUtils();
/** Instance variable that stores the suffix for the weblogic jarfile. */
private String jarSuffix = ".jar";
/** Instance variable that stores the location of the weblogic DTD file. */
private String weblogicDTD;
- /** Instance variable that stores the location of the ejb 1.1 DTD file. */
+ /** Instance variable that stores the location of the EJB 1.1 DTD file. */
private String ejb11DTD;
/** Instance variable that determines whether generic ejb jars are kept. */
@@ -115,7 +115,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
/**
* Instance variable that stores the fully qualified classname of the
* weblogic EJBC compiler
*/
private String ejbcClass = null;
@@ -138,7 +138,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
/** Indicates if the old CMP location convention is to be used. */
private boolean newCMP = false;
/** The classpath to the weblogic classes. */
private Path wlClasspath = null;
/** System properties for the JVM. */
@@ -162,7 +162,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
}
/**
* Get the classpath to the weblogic classpaths.
* @return the classpath to configure.
*/
public Path createWLClasspath() {
@@ -184,9 +184,9 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
/**
* Optional classpath to WL6.0.
* Weblogic 6.0 will give a warning if the home and remote interfaces
* of a bean are on the system classpath used to run weblogic.ejbc.
* In that case, the standard weblogic classes should be set with
* this attribute (or equivalent nested element) and the
* home and remote interfaces located with the standard classpath
* attribute.
@@ -246,7 +246,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
}
/**
- * Setter used to store the suffix for the generated weblogic jar file.
+ * Setter used to store the suffix for the generated WebLogic jar file.
*
* @param inString the string to use as the suffix.
*/
@@ -265,7 +265,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
}
/**
- * Controls whether weblogic will keep the generated Java
+ * Controls whether WebLogic will keep the generated Java
* files used to build the class files added to the
* jar. This can be useful when debugging; default is false.
*
@@ -285,7 +285,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
}
/**
* Set any additional arguments to pass to the weblogic JVM; optional.
* @param args the arguments to be passed to the JVM
*/
public void setJvmargs(String args) {
@@ -296,7 +296,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
* Set the classname of the ejbc compiler; optional
* Normally ejbjar determines
* the appropriate class based on the DTD used for the EJB. The EJB 2.0 compiler
* featured in weblogic 6 has, however, been deprecated in version 7. When
* using with version 7 this attribute should be set to
* &quot;weblogic.ejbc&quot; to avoid the deprecation warning.
* @param ejbcClass the name of the class to use.
@@ -315,7 +315,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
/**
* <b>Deprecated</b>. Defines the location of the ejb-jar DTD in
* the weblogic class hierarchy. Should not be needed, and the
* nested &lt;dtd&gt; element is recommended when it is.
*
* @param inString the string to use as the DTD location.
@@ -325,8 +325,8 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
}
/**
* <b>Deprecated</b>. Defines the location of weblogic DTD in
* the weblogic class hierarchy. Should not be needed, and the
* nested &lt;dtd&gt; element is recommended when it is.
*
* @param inString the string to use as the DTD location.
@@ -337,7 +337,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
/**
* <b>Deprecated</b>. Defines the location of Sun's EJB DTD in
* the weblogic class hierarchy. Should not be needed, and the
* nested &lt;dtd&gt; element is recommended when it is.
*
* @param inString the string to use as the DTD location.
@@ -360,10 +360,10 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
* CMP descriptors will be used; optional, default false.
* <P>
* The old CMP scheme locates the
* weblogic CMP descriptor based on the naming convention where the
* weblogic CMP file is expected to be named with the bean name as the
* prefix. Under this scheme the name of the CMP descriptor does not match
* the name actually used in the main weblogic EJB descriptor. Also,
* descriptors which contain multiple CMP references could not be used.
* @param newCMP a <code>boolean</code> value.
*/
@@ -394,7 +394,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
}
/**
* Get the weblogic descriptor handler.
* @param srcDir the source directory.
* @return the descriptor.
*/
@@ -452,14 +452,14 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
log("The old method for locating CMP files has been DEPRECATED.", Project.MSG_VERBOSE);
log("Please adjust your weblogic descriptor and set newCMP=\"true\" to use the new CMP descriptor inclusion mechanism. ",
Project.MSG_VERBOSE);
// The the weblogic cmp deployment descriptor
File weblogicCMPDD = new File(getConfig().descriptorDir, ddPrefix + WL_CMP_DD);
if (weblogicCMPDD.exists()) {
ejbFiles.put(META_DIR + WL_CMP_DD, weblogicCMPDD);
}
} else {
// now that we have the weblogic descriptor, we parse the file
// to find other descriptors needed to deploy the bean.
// this could be the weblogic-cmp-rdbms.xml or any other O/R
// mapping tool descriptors.
@@ -641,27 +641,27 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
}
/**
* Helper method to check to see if a weblogic EBJ1.1 jar needs to be
* rebuilt using ejbc. Called from writeJar it sees if the "Bean" classes
* are the only thing that needs to be updated and either updates the Jar
- * with the Bean classfile or returns true, saying that the whole weblogic
- * jar needs to be regened with ejbc. This allows faster build times for
+ * with the Bean classfile or returns true, saying that the whole WebLogic
+ * jar needs to be regenerated with ejbc. This allows faster build times for
* working developers. <p>
*
* The way weblogic ejbc works is it creates wrappers for the publicly
* defined methods as they are exposed in the remote interface. If the
* actual bean changes without changing the the method signatures then
* only the bean classfile needs to be updated and the rest of the
* weblogic jar file can remain the same. If the Interfaces, ie. the
* method signatures change or if the xml deployment descriptors changed,
* the whole jar needs to be rebuilt with ejbc. This is not strictly true
* for the xml files. If the JNDI name changes then the jar doesn't have to
* be rebuild, but if the resources references change then it does. At
* this point the weblogic jar gets rebuilt if the xml files change at
* all.
*
* @param genericJarFile java.io.File The generic jar file.
* @param weblogicJarFile java.io.File The weblogic jar file to check to
* see if it needs to be rebuilt.
* @return true if the jar needs to be rebuilt.
*/
@@ -678,7 +678,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
try {
log("Checking if weblogic Jar needs to be rebuilt for jar " + weblogicJarFile.getName(),
Project.MSG_VERBOSE);
// Only go forward if the generic and the weblogic file both exist
if (genericJarFile.exists() && genericJarFile.isFile()
&& weblogicJarFile.exists() && weblogicJarFile.isFile()) {
//open jar files
@@ -694,13 +694,13 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
JarEntry je = e.nextElement();
genericEntries.put(je.getName().replace('\\', '/'), je);
}
//get the list of weblogic jar entries
for (Enumeration<JarEntry> e = wlJar.entries(); e.hasMoreElements();) {
JarEntry je = e.nextElement();
wlEntries.put(je.getName(), je);
}
//Cycle Through generic and make sure its in weblogic
genericLoader = getClassLoaderFromJar(genericJarFile);
for (Enumeration<String> e = genericEntries.keys(); e.hasMoreElements();) {
@@ -765,7 +765,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
newJarStream = new JarOutputStream(Files.newOutputStream(newWLJarFile.toPath()));
newJarStream.setLevel(0);
//Copy files from old weblogic jar
for (Enumeration<JarEntry> e = wlEntries.elements(); e.hasMoreElements();) {
JarEntry je = e.nextElement();
@@ -785,7 +785,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
je = replaceEntries.get(je.getName());
is = genericJar.getInputStream(je);
} else {
//use fle from original weblogic jar
is = wlJar.getInputStream(je);
}
@@ -61,23 +61,23 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
public static final String PUBLICID_WEBLOGIC_EJB700
= "-//BEA Systems, Inc.//DTD WebLogic 7.0.0 EJB//EN";
- /** Weblogic 5.1 dtd location */
+ /** WebLogic 5.1 dtd location */
protected static final String DEFAULT_WL51_EJB11_DTD_LOCATION
= "/weblogic/ejb/deployment/xml/ejb-jar.dtd";
@@ -61,23 +61,23 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
protected static final String DEFAULT_WL51_EJB11_DTD_LOCATION
= "/weblogic/ejb/deployment/xml/ejb-jar.dtd";
- /** Weblogic 6.0 ejb 1.1 dtd location */
+ /** WebLogic 6.0 ejb 1.1 dtd location */
protected static final String DEFAULT_WL60_EJB11_DTD_LOCATION
= "/weblogic/ejb20/dd/xml/ejb11-jar.dtd";
@@ -61,23 +61,23 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
protected static final String DEFAULT_WL60_EJB11_DTD_LOCATION
= "/weblogic/ejb20/dd/xml/ejb11-jar.dtd";
- /** Weblogic 6.0 ejb 2.0 dtd location */
+ /** WebLogic 6.0 ejb 2.0 dtd location */
protected static final String DEFAULT_WL60_EJB20_DTD_LOCATION
= "/weblogic/ejb20/dd/xml/ejb20-jar.dtd";
@@ -101,13 +101,13 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
/** File utilities instance for copying jars */
private static final FileUtils FILE_UTILS = FileUtils.getFileUtils();
- /** Instance variable that stores the suffix for the weblogic jarfile. */
+ /** Instance variable that stores the suffix for the WebLogic jarfile. */
private String jarSuffix = ".jar";
@@ -101,13 +101,13 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
private String jarSuffix = ".jar";
- /** Instance variable that stores the location of the weblogic DTD file. */
+ /** Instance variable that stores the location of the WebLogic DTD file. */
private String weblogicDTD;
@@ -115,7 +115,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
/**
* Instance variable that stores the fully qualified classname of the
- * weblogic EJBC compiler
+ * WebLogic EJBC compiler
*/
private String ejbcClass = null;
@@ -138,7 +138,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
/** Indicates if the old CMP location convention is to be used. */
private boolean newCMP = false;
- /** The classpath to the weblogic classes. */
+ /** The classpath to the WebLogic classes. */
private Path wlClasspath = null;
/** System properties for the JVM. */
@@ -162,7 +162,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
}
/**
- * Get the classpath to the weblogic classpaths.
+ * Get the classpath to the WebLogic classpaths.
* @return the classpath to configure.
*/
@@ -184,9 +184,9 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
/**
* Optional classpath to WL6.0.
- * Weblogic 6.0 will give a warning if the home and remote interfaces
+ * WebLogic 6.0 will give a warning if the home and remote interfaces
* of a bean are on the system classpath used to run weblogic.ejbc.
@@ -184,9 +184,9 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
* of a bean are on the system classpath used to run weblogic.ejbc.
- * In that case, the standard weblogic classes should be set with
+ * In that case, the standard WebLogic classes should be set with
* this attribute (or equivalent nested element) and the
* home and remote interfaces located with the standard classpath
@@ -285,7 +285,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
}
/**
- * Set any additional arguments to pass to the weblogic JVM; optional.
+ * Set any additional arguments to pass to the WebLogic JVM; optional.
* @param args the arguments to be passed to the JVM
*/
@@ -296,7 +296,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
* Normally ejbjar determines
* the appropriate class based on the DTD used for the EJB. The EJB 2.0 compiler
- * featured in weblogic 6 has, however, been deprecated in version 7. When
+ * featured in WebLogic 6 has, however, been deprecated in version 7. When
* using with version 7 this attribute should be set to
* &quot;weblogic.ejbc&quot; to avoid the deprecation warning.
@@ -315,7 +315,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
/**
* <b>Deprecated</b>. Defines the location of the ejb-jar DTD in
- * the weblogic class hierarchy. Should not be needed, and the
+ * the WebLogic class hierarchy. Should not be needed, and the
* nested &lt;dtd&gt; element is recommended when it is.
*
@@ -325,8 +325,8 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
}
/**
- * <b>Deprecated</b>. Defines the location of weblogic DTD in
- * the weblogic class hierarchy. Should not be needed, and the
+ * <b>Deprecated</b>. Defines the location of WebLogic DTD in
+ * the WebLogic class hierarchy. Should not be needed, and the
* nested &lt;dtd&gt; element is recommended when it is.
*
@@ -337,7 +337,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
/**
* <b>Deprecated</b>. Defines the location of Sun's EJB DTD in
- * the weblogic class hierarchy. Should not be needed, and the
+ * the WebLogic class hierarchy. Should not be needed, and the
* nested &lt;dtd&gt; element is recommended when it is.
*
@@ -360,10 +360,10 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
* <P>
* The old CMP scheme locates the
- * weblogic CMP descriptor based on the naming convention where the
- * weblogic CMP file is expected to be named with the bean name as the
+ * WebLogic CMP descriptor based on the naming convention where the
+ * WebLogic CMP file is expected to be named with the bean name as the
* prefix. Under this scheme the name of the CMP descriptor does not match
@@ -360,10 +360,10 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
* prefix. Under this scheme the name of the CMP descriptor does not match
- * the name actually used in the main weblogic EJB descriptor. Also,
+ * the name actually used in the main WebLogic EJB descriptor. Also,
* descriptors which contain multiple CMP references could not be used.
* @param newCMP a <code>boolean</code> value.
@@ -394,7 +394,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
}
/**
- * Get the weblogic descriptor handler.
+ * Get the WebLogic descriptor handler.
* @param srcDir the source directory.
* @return the descriptor.
@@ -452,14 +452,14 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
log("Please adjust your weblogic descriptor and set newCMP=\"true\" to use the new CMP descriptor inclusion mechanism. ",
Project.MSG_VERBOSE);
- // The the weblogic cmp deployment descriptor
+ // The the WebLogic CMP deployment descriptor
File weblogicCMPDD = new File(getConfig().descriptorDir, ddPrefix + WL_CMP_DD);
if (weblogicCMPDD.exists()) {
@@ -452,14 +452,14 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
}
} else {
- // now that we have the weblogic descriptor, we parse the file
+ // now that we have the WebLogic descriptor, we parse the file
// to find other descriptors needed to deploy the bean.
// this could be the weblogic-cmp-rdbms.xml or any other O/R
@@ -641,27 +641,27 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
}
/**
- * Helper method to check to see if a weblogic EBJ1.1 jar needs to be
+ * Helper method to check to see if a WebLogic EJB 1.1 jar needs to be
* rebuilt using ejbc. Called from writeJar it sees if the "Bean" classes
* are the only thing that needs to be updated and either updates the Jar
@@ -641,27 +641,27 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
* working developers. <p>
*
- * The way weblogic ejbc works is it creates wrappers for the publicly
+ * The way WebLogic ejbc works is it creates wrappers for the publicly
* defined methods as they are exposed in the remote interface. If the
* actual bean changes without changing the the method signatures then
@@ -641,27 +641,27 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
* actual bean changes without changing the the method signatures then
* only the bean classfile needs to be updated and the rest of the
- * weblogic jar file can remain the same. If the Interfaces, ie. the
+ * WebLogic jar file can remain the same. If the Interfaces, ie. the
* method signatures change or if the xml deployment descriptors changed,
* the whole jar needs to be rebuilt with ejbc. This is not strictly true
@@ -641,27 +641,27 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
* for the xml files. If the JNDI name changes then the jar doesn't have to
* be rebuild, but if the resources references change then it does. At
- * this point the weblogic jar gets rebuilt if the xml files change at
+ * this point the WebLogic jar gets rebuilt if the xml files change at
* all.
*
@@ -641,27 +641,27 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
*
* @param genericJarFile java.io.File The generic jar file.
- * @param weblogicJarFile java.io.File The weblogic jar file to check to
+ * @param weblogicJarFile java.io.File The WebLogic jar file to check to
* see if it needs to be rebuilt.
* @return true if the jar needs to be rebuilt.
@@ -678,7 +678,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
log("Checking if weblogic Jar needs to be rebuilt for jar " + weblogicJarFile.getName(),
Project.MSG_VERBOSE);
- // Only go forward if the generic and the weblogic file both exist
+ // Only go forward if the generic and the WebLogic file both exist
if (genericJarFile.exists() && genericJarFile.isFile()
&& weblogicJarFile.exists() && weblogicJarFile.isFile()) {
@@ -694,13 +694,13 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
genericEntries.put(je.getName().replace('\\', '/'), je);
}
- //get the list of weblogic jar entries
+ // get the list of WebLogic jar entries
for (Enumeration<JarEntry> e = wlJar.entries(); e.hasMoreElements();) {
JarEntry je = e.nextElement();
@@ -694,13 +694,13 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
wlEntries.put(je.getName(), je);
}
- //Cycle Through generic and make sure its in weblogic
+ // Cycle through generic and make sure its in WebLogic
genericLoader = getClassLoaderFromJar(genericJarFile);
for (Enumeration<String> e = genericEntries.keys(); e.hasMoreElements();) {
@@ -765,7 +765,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
newJarStream = new JarOutputStream(Files.newOutputStream(newWLJarFile.toPath()));
newJarStream.setLevel(0);
- //Copy files from old weblogic jar
+ // Copy files from old WebLogic jar
for (Enumeration<JarEntry> e = wlEntries.elements(); e.hasMoreElements();) {
JarEntry je = e.nextElement();
@@ -785,7 +785,7 @@ public class WeblogicDeploymentTool extends GenericDeploymentTool {
is = genericJar.getInputStream(je);
} else {
- //use fle from original weblogic jar
+ //use file from original WebLogic jar
is = wlJar.getInputStream(je);
}